'use strict';

var vue = require('vue');

var script = {
  name: "Icon",
  props: {
    path: String,
    size: {
      type: [String, Number],
      default: 24,
    },
    color: {
      type: String,
      default: "#000",
    },
    spin: {
      type: Boolean,
      default: false,
    },
    pulse: {
      type: Boolean,
      default: false,
    },
  },
  setup(props) {
    const onePx = 0.041666666666666664; //i scale equals 24px. so one px equals 0.041666666666666664 in scale.

    function getAnimations() {
      const animations = [];
      if (this.props.spin) {
        animations.push("spin-right-infinite");
      }
      if (this.props.pulse) {
        animations.push("pulse-infinite");
      }
      return animations.length ? animations.join(" ") : null;
    }
    return {
      props,
      getAnimations,
      onePx,
    };
  },
};

const _hoisted_1 = { class: "svg-icon--box" };
const _hoisted_2 = ["d", "fill"];

function render(_ctx, _cache, $props, $setup, $data, $options) {
  return (vue.openBlock(), vue.createElementBlock("div", _hoisted_1, [
    (vue.openBlock(), vue.createElementBlock("svg", {
      viewbox: "0 0 50 50",
      style: vue.normalizeStyle(`height:${$props.size}px; width:${$props.size}px;`),
      class: vue.normalizeClass($setup.getAnimations())
    }, [
      vue.createElementVNode("path", {
        d: $setup.props.path,
        fill: $setup.props.color,
        style: vue.normalizeStyle('transform:scale(' + $setup.props.size * $setup.onePx + ');')
      }, null, 12 /* STYLE, PROPS */, _hoisted_2)
    ], 6 /* CLASS, STYLE */))
  ]))
}

script.render = render;
script.__scopeId = "data-v-fd312f28";
script.__file = "src/MdiToIconComp.vue";

var components = {Icon: script};

const mdiToIcon = {
    install(Vue) {
        for (const prop in components) {
            if (components.hasOwnProperty(prop)) {
                const component = components[prop];
                Vue.component(component.name, component);
            }
        }
    }
};

module.exports = mdiToIcon;
